from rest_framework import serializers

try:
    from functools import reduce
except:
    # pyton 2 has reduce builtin
    pass


class PrettifyDataFromJsonField(serializers.Field):
    """
    Instead of using the field_name, for the value rather use the source
    as then we can massage ugly json data
    """
    def get_value(self, dictionary):
        if self.source is not None:
            data_source = self.source
        else:
            data_source = self.field_name

        if data_source not in dictionary:
            if getattr(self.root, 'partial', False):
                return serializers.empty
        # We override the default field access in order to support
        # lists in HTML forms.
        if serializers.html.is_html_input(dictionary):
            return dictionary.getlist(data_source)
        # account for dot notation
        if '.' in data_source:
            return reduce(dict.get, data_source.split('.'), dictionary)
        return dictionary.get(data_source, serializers.empty)


class CharField(PrettifyDataFromJsonField, serializers.CharField):
    pass


class EmailField(PrettifyDataFromJsonField, serializers.EmailField):
    pass


class DecimalField(PrettifyDataFromJsonField, serializers.DecimalField):
    pass


class IntegerField(PrettifyDataFromJsonField, serializers.IntegerField):
    pass


from setuptools import setup, find_packages


setup(
    name='drf_prettify_json_serializer_field',
    version='0.3.0',
    description='You got ugly json, we got a serializer that can massage that data into something useful',
    long_description='Serialize ugly json to pretty json',
    keywords='djangorestframework serializer field json massage presenter-pattern',
    url='https://github.com/rosscdh/drf-prettify-json_serializer-field/',
    author="Ross Crawford-d'Heureuse",
    author_email='sendrossemail@gmail.com',
    license='MIT',
    python_requires='>=3.5',
    install_requires=[
    ],
    classifiers=[
        'Development Status :: 5 - Production/Stable',
        'Intended Audience :: Developers',
        'Intended Audience :: Information Technology',
        'License :: OSI Approved :: MIT License',
        'Programming Language :: Python',
        'Programming Language :: Python :: 3 :: Only',
        'Programming Language :: Python :: 3.5',
        'Programming Language :: Python :: 3.6',
        'Programming Language :: Python :: 3.7'
    ],
    packages=find_packages(exclude=['*.tests'])
)



from drf_prettify_json_serializer_field.fields import PrettifyDataFromJsonField
from drf_prettify_json_serializer_field.fields import (Charfield,
                                                       EmailField,
                                                       DecimalField,
                                                       IntegerField)
